exceptiontools.InstrumentError
==============================

.. abjad-lineage:: abjad.tools.exceptiontools.InstrumentError.InstrumentError

.. autoclass:: abjad.tools.exceptiontools.InstrumentError.InstrumentError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.InstrumentError.InstrumentError.__unicode__
   :noindex:
